# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-05-20 10:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perimeter', '0004_auto_20170407_0639'),
    ]

    operations = [
        migrations.AlterField(
            model_name='accesstokenuse',
            name='client_user_agent',
            field=models.TextField(blank=True, verbose_name='Client User Agent'),
        ),
    ]
